@@ -48,5 +48,5 @@ def main():
     parser.dispatch()
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
