@@ -69,6 +69,7 @@ You can add RST documentation directly in the source files.
 """
 
 from pathlib import Path
+
 _STATIC_FILES = Path(__file__).absolute().parent / '_static'
 
 from epythet.docs_gen.autogen import make_autodocs
@@ -78,17 +79,14 @@ from epythet.docs_gen.call_make import make
 
 argh_kwargs = {
     'namespace': 'docs_gen',
-    'functions': [
-        make_docsrc,
-        make_autodocs,
-        make,
-    ],
+    'functions': [make_docsrc, make_autodocs, make,],
     'namespace_kwargs': {
         'title': 'Documentation Generator',
-        'description': 'Setup and generate Sphinx docs effortlessly'
-    }
+        'description': 'Setup and generate Sphinx docs effortlessly',
+    },
 }
 
 if __name__ == '__main__':
     import argh  # pip install argh
+
     argh.dispatch_commands(argh_kwargs.get('functions', None))
